@@ -50,7 +50,6 @@ def split_trips(pins, sld_tolerance, min_pause_duration):
     detecting = []
     mode = 0  # 0: travelling 1: detecting pause 2: pausing
     for pin in pins[1:]:
-        #print(mode, pin)
         if mode == 0:
             if distance(pin.to_latlng(), last.to_latlng()) <= sld_tolerance:
                 start = last
@@ -115,23 +114,24 @@ def distance(loc1: LatLng, loc2: LatLng):
 
 def geojson_to_poly(gjson: str, name: str = None):
     loaded = json.loads(gjson)
-    if name == None:
-        if'name' in loaded:
+    if not name:
+        if 'name' in loaded:
             name = loaded['name']
         else:
             name = 'default'
-    if len(loaded['features']) > 1:
-        raise ValueError('multiple features geojson is not supported')
-    geometry = loaded['features'][0]['geometry']
-    if geometry['type'] != 'Polygon':
-        raise ValueError('only converting from geojson polygon is supported')
-    if len(geometry['coordinates']) > 1:
-        logging.warn(
-            'multiple coordinates of polygon detected, only using first one as exterior definition')
-    output = [name, 'area1']
-    for coord in geometry['coordinates'][0]:
-        output.append(f'\t{coord[0]}\t{coord[1]}')
-    output.append('END')
+    output = [name]
+    features = loaded['features']
+    for f in features:
+        geometry = f['geometry']
+        if geometry['type'] != 'Polygon':
+            raise ValueError('only converting from geojson polygon is supported')
+        if len(geometry['coordinates']) > 1:
+            logging.warn(
+                'multiple coordinates of polygon detected, only using first one as exterior definition')
+        output.append('area1')
+        for coord in geometry['coordinates'][0]:
+            output.append(f'\t{coord[0]}\t{coord[1]}')
+        output.append('END')
     output.append('END')
     return '\n'.join(output)
 
