@@ -1,4 +1,5 @@
 import asyncio
+import inspect
 
 """
 table_split helps calculating  a large horizontal * vertical using multiple batches currently with func(horizontal, vertical) => List[List[result]]
@@ -7,29 +8,25 @@ horizontal: list/slice length of n
 func: awaitable
 result: 2d array of dimention m*n
 """
-_unit = 100
 
 
-async def table_split(vertical, horizontal, func):
+async def table_split(vertical, horizontal, func, unit=100, return_exceptions=False):
     async def executor(vi, hi):
-        is_crt = asyncio.iscoroutinefunction(func)
-        r = None
-        if is_crt:
-            r = await func(vertical[vi:vi + _unit], horizontal[hi:hi + _unit])
-        else:
-            r = func(vertical[vi:vi + _unit], horizontal[hi:hi + _unit])
+        r = func(vertical[vi:vi + unit], horizontal[hi:hi + unit])
+        if inspect.isawaitable(r):
+            r = await(r)
 
         for i in range(0, len(r)):
             for j in range(0, len(r[i])):
                 result[vi + i][hi + j] = r[i][j]
     result = [[None for j in range(0, len(horizontal))] for i in range(0, len(vertical))]
     vi = 0
-    hi = 0
     execs = []
     while vi < len(vertical):
+        hi = 0
         while hi < len(horizontal):
             execs.append(executor(vi, hi))
-            hi += _unit
-        vi += _unit
-    await asyncio.gather(*execs)
+            hi += unit
+        vi += unit
+    await asyncio.gather(*execs, return_exceptions=return_exceptions)
     return result
